@@ -1,8 +1,9 @@
 use super::utils::fetch_symbols_retry;
 use crate::crawlers::crawl_event;
 use crate::crawlers::utils::create_conversion_thread;
-use crate::{msg::Message, MessageType};
-use crypto_markets::MarketType;
+use crate::msg::Message;
+use crypto_market_type::MarketType;
+use crypto_msg_type::MessageType;
 use crypto_ws_client::*;
 use std::sync::mpsc::Sender;
 
