@@ -1,4 +1,6 @@
 pub(crate) mod cmc_rank;
+mod lock;
 pub(crate) mod spot_symbols;
 
+pub(crate) use lock::{REST_LOCKS, WS_LOCKS};
 pub use spot_symbols::get_hot_spot_symbols;
