@@ -152,3 +152,13 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
+
+#[test_case(MarketType::Spot, "BTC-USDT")]
+#[test_case(MarketType::InverseFuture, "BTC-USD-211231")]
+#[test_case(MarketType::LinearFuture, "BTC-USDT-211231")]
+#[test_case(MarketType::InverseSwap, "BTC-USD-SWAP")]
+#[test_case(MarketType::LinearSwap, "BTC-USDT-SWAP")]
+#[test_case(MarketType::EuropeanOption, "BTC-USD-211231-18000-P")]
+fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
+    gen_test_subscribe_symbol!(EXCHANGE_NAME, market_type, symbol)
+}
